<!DOCTYPE html>
<html lang="en">
<head>
    <title>{% block title %}{% endblock %}</title>
    <link rel="shortcut icon" href="{{ url_for('static', filename='favicon.ico') }}">
    <script src="https://kit.fontawesome.com/9da1ddd86e.js" crossorigin="anonymous"></script>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-select@1.13.14/dist/css/bootstrap-select.min.css">
    {% block head %}
    {% endblock %}
</head>
<body class="bg-muted">
    <nav class="navbar navbar-dark bg-dark navbar-fixed-top">
            <ul class="nav nav-pills nav-fill">
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle text-light" data-toggle="dropdown" href="#" role="button" aria-haspopup="true" aria-expanded="false">
                        <i class="text-light fas fa-bars"></i></a>
                    <div class="dropdown-menu bg-dark">
                        <a class="dropdown-item text-light" href="/_help"><i class="nav-item fas fa-question-circle"></i> Help</a>
                        <a class="dropdown-item text-light" href="https://git.admin.franklin.edu/tins/shorty/issues" title="Report issues or request features"><i class="nav-item fas fa-bug"></i> Issues</a>
                        {% if 'admin' in permissions %}
                            <a class="dropdown-item text-light" href="/_admin" title="Administrative features"><i class="nav-item fas fa-user-shield"></i> Administration</a>
                        {% endif %}
                        <div class="dropdown-divider"></div>
                        <a class="dropdown-item text-light" href="/_logout"><i class="nav-item fas fa-sign-out-alt"></i> Logout</a>
                    </div>
                <li class="nav-link">
                    <a class="text-light" href="/"><i class="nav-item fas fa-home"></i> Home</a>
                </li>
                <li class="nav-link">
                    <a class="text-light" href="/_mylinks"><i class="nav-item fas fa-external-link-alt"></i> My Shortcuts</a>
                </li>
            </ul>
    </nav>
    {% block body %}
    {% endblock %}
    <footer>
        {% block footer %}
        {% endblock %}
        <div class="fixed-bottom text-secondary">
        <small class="pull-right">
            version:
            <a class="text-muted" title="View the changelog" href="{{ metainfo['changelog'] }}">{{ metainfo['version'] }}</a>
        </small>
        </div>
    </footer>
    <script src="https://code.jquery.com/jquery-3.5.1.min.js" integrity="sha256-9/aliU8dGd2tb6OSsuzixeV4y/faTqgFtohetphbbj0=" crossorigin="anonymous"></script>
    <script src="https://cdn.jsdelivr.net/npm/popper.js@1.16.0/dist/umd/popper.min.js" integrity="sha384-Q6E9RHvbIyZFJoft+2mJbHaEWldlvI9IOYy5n3zV9zzTtmI3UksdQRVvoxMfooAo" crossorigin="anonymous"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap-select@1.13.14/dist/js/bootstrap-select.min.js"></script>
</body>
</html>