{% extends "base.html" %}
{% block body %}
<div class="jumbotron">
    <div class="container">
        <br />
                <div class="alert alert-danger" role="alert">
                <h1><i class="nav-item fas fa-exclamation-triangle"></i>The shortlink &quot;{{ url }}&quot; is not valid</h1>
                </div>
    </div>
    {% endblock %}
