{% extends "base.html" %}
{% block body %}
<div class="jumbotron">
    <div class="container position-top">
<ul class="nav nav-tabs" id="myTab" role="tablist">
  <li class="nav-item">
    <a class="nav-link active" id="user-tab" data-toggle="tab" href="#home" role="tab" aria-controls="users"
      aria-selected="true">Users</a>
  </li>
  <li class="nav-item">
    <a class="nav-link" id="link-tab" data-toggle="tab" href="#profile" role="tab" aria-controls="links"
      aria-selected="false">Links</a>
  </li>
</ul>
<div class="tab-content" id="myTabContent">
  <div class="tab-pane fade show active" id="home" role="tabpanel" aria-labelledby="user-tab">
      <p>user stuff</p>
  </div>
  <div class="tab-pane fade" id="profile" role="tabpanel" aria-labelledby="link-tab">
  </div>
    </div>
</div>
    {% endblock %}
