    -- :name my_create_namespace_table
        CREATE TABLE namespace(
        id INTEGER PRIMARY KEY AUTO_INCREMENT,
        name varchar(25),
        description varchar(255),
        icon varchar(25)
        );
